mocks

package
v0.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 20, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type IPricingAPI

type IPricingAPI struct {
	mock.Mock
}

IPricingAPI is an autogenerated mock type for the IPricingAPI type

func NewIPricingAPI

func NewIPricingAPI(t interface {
	mock.TestingT
	Cleanup(func())
}) *IPricingAPI

NewIPricingAPI creates a new instance of IPricingAPI. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*IPricingAPI) GetProducts

func (_m *IPricingAPI) GetProducts(ctx context.Context, params *pricing.GetProductsInput, optFns ...func(*pricing.Options)) (*pricing.GetProductsOutput, error)

GetProducts provides a mock function with given fields: ctx, params, optFns

Jump to