Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IPricingAPI ¶
IPricingAPI is an autogenerated mock type for the IPricingAPI type
func NewIPricingAPI ¶
func NewIPricingAPI(t interface {
mock.TestingT
Cleanup(func())
}) *IPricingAPI
NewIPricingAPI creates a new instance of IPricingAPI. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*IPricingAPI) GetProducts ¶
func (_m *IPricingAPI) GetProducts(ctx context.Context, params *pricing.GetProductsInput, optFns ...func(*pricing.Options)) (*pricing.GetProductsOutput, error)
GetProducts provides a mock function with given fields: ctx, params, optFns
Click to show internal directories.
Click to hide internal directories.